svn commit: r215956 - in head/sys: netinet netinet6

Bruce Cran brucec at FreeBSD.org
Sat Nov 27 21:51:40 UTC 2010


Author: brucec
Date: Sat Nov 27 21:51:39 2010
New Revision: 215956
URL: http://svn.freebsd.org/changeset/base/215956

Log:
  Fix more continuous/contiguous typos (cf. r215955)

Modified:
  head/sys/netinet/ip6.h
  head/sys/netinet6/in6_cksum.c
  head/sys/netinet6/ip6_input.c
  head/sys/netinet6/ip6_output.c
  head/sys/netinet6/ip6_var.h

Modified: head/sys/netinet/ip6.h
==============================================================================
--- head/sys/netinet/ip6.h	Sat Nov 27 21:35:16 2010	(r215955)
+++ head/sys/netinet/ip6.h	Sat Nov 27 21:51:39 2010	(r215956)
@@ -263,7 +263,7 @@ struct ip6_frag {
 /*
  * IP6_EXTHDR_CHECK ensures that region between the IP6 header and the
  * target header (including IPv6 itself, extension headers and
- * TCP/UDP/ICMP6 headers) are continuous. KAME requires drivers
+ * TCP/UDP/ICMP6 headers) are contiguous. KAME requires drivers
  * to store incoming data into one internal mbuf or one or more external
  * mbufs(never into two or more internal mbufs). Thus, the third case is
  * supposed to never be matched but is prepared just in case.

Modified: head/sys/netinet6/in6_cksum.c
==============================================================================
--- head/sys/netinet6/in6_cksum.c	Sat Nov 27 21:35:16 2010	(r215955)
+++ head/sys/netinet6/in6_cksum.c	Sat Nov 27 21:51:39 2010	(r215956)
@@ -81,7 +81,7 @@ __FBSDID("$FreeBSD$");
 #define REDUCE {l_util.l = sum; sum = l_util.s[0] + l_util.s[1]; (void)ADDCARRY(sum);}
 
 /*
- * m MUST contain a continuous IP6 header.
+ * m MUST contain a contiguous IP6 header.
  * off is an offset where TCP/UDP/ICMP6 header starts.
  * len is a total length of a transport segment.
  * (e.g. TCP header + TCP payload)

Modified: head/sys/netinet6/ip6_input.c
==============================================================================
--- head/sys/netinet6/ip6_input.c	Sat Nov 27 21:35:16 2010	(r215955)
+++ head/sys/netinet6/ip6_input.c	Sat Nov 27 21:51:39 2010	(r215956)
@@ -1058,7 +1058,7 @@ ip6_hopopts_input(u_int32_t *plenp, u_in
  *
  * The function assumes that hbh header is located right after the IPv6 header
  * (RFC2460 p7), opthead is pointer into data content in m, and opthead to
- * opthead + hbhlen is located in continuous memory region.
+ * opthead + hbhlen is located in contiguous memory region.
  */
 int
 ip6_process_hopopts(struct mbuf *m, u_int8_t *opthead, int hbhlen,
@@ -1191,7 +1191,7 @@ ip6_process_hopopts(struct mbuf *m, u_in
  * Unknown option processing.
  * The third argument `off' is the offset from the IPv6 header to the option,
  * which is necessary if the IPv6 header the and option header and IPv6 header
- * is not continuous in order to return an ICMPv6 error.
+ * is not contiguous in order to return an ICMPv6 error.
  */
 int
 ip6_unknown_opt(u_int8_t *optp, struct mbuf *m, int off)

Modified: head/sys/netinet6/ip6_output.c
==============================================================================
--- head/sys/netinet6/ip6_var.h	Sat Nov 27 21:35:16 2010	(r215955)
+++ head/sys/netinet6/ip6_var.h	Sat Nov 27 21:51:39 2010	(r215956)
@@ -209,7 +209,7 @@ struct	ip6stat {
 	u_quad_t ip6s_m2m[32];		/* two or more mbuf */
 	u_quad_t ip6s_mext1;		/* one ext mbuf */
 	u_quad_t ip6s_mext2m;		/* two or more ext mbuf */
-	u_quad_t ip6s_exthdrtoolong;	/* ext hdr are not continuous */
+	u_quad_t ip6s_exthdrtoolong;	/* ext hdr are not contiguous */
 	u_quad_t ip6s_nogif;		/* no match gif found */
 	u_quad_t ip6s_toomanyhdr;	/* discarded due to too many headers */
 


More information about the svn-src-all mailing list
--- head/sys/netinet6/ip6_output.c	Sat Nov 27 21:35:16 2010	(r215955)
+++ head/sys/netinet6/ip6_output.c	Sat Nov 27 21:51:39 2010	(r215956)
@@ -814,13 +814,13 @@ again:
 
 #ifdef DIAGNOSTIC
 		if ((hbh->ip6h_len + 1) << 3 > exthdrs.ip6e_hbh->m_len)
-			panic("ip6e_hbh is not continuous");
+			panic("ip6e_hbh is not contiguous");
 #endif
 		/*
 		 *  XXX: if we have to send an ICMPv6 error to the sender,
 		 *       we need the M_LOOP flag since icmp6_error() expects
 		 *       the IPv6 and the hop-by-hop options header are
 		 *       continuous unless the flag is set.
 		 */
 		m->m_flags |= M_LOOP;
 		m->m_pkthdr.rcvif = ifp;
@@ -814,13 +814,13 @@ again:
 		 *       we need the M_LOOP flag since icmp6_error() expects
 		 *       the IPv6 and the hop-by-hop options header are
-		 *       continuous unless the flag is set.
+		 *       contiguous unless the flag is set.
 		 */
 		m->m_flags |= M_LOOP;

Modified: head/sys/netinet6/ip6_var.h
==============================================================================